@@ -14,7 +14,7 @@ APPLE_MFR_ID = 76
 IBEACON_FIRST_BYTE = 0x02
 IBEACON_SECOND_BYTE = 0x15
 
-__version__ = "0.6.0"
+__version__ = "0.6.1"
 
 __all__ = [
     "parse",
@@ -61,6 +61,7 @@ def parse(service_info: BluetoothServiceInfo) -> iBeaconAdvertisement | None:
     # Thanks to https://github.com/custom-components/ble_monitor/blob/master/custom_components/ble_monitor/ble_parser/ibeacon.py
     uuid = data[2:18]
     (major, minor, power) = UNPACK_IBEACON(data[18:23])
+    distance = calculate_distance_meters(power, service_info.rssi)
 
     return iBeaconAdvertisement(
         name=service_info.name,
@@ -72,7 +73,7 @@ def parse(service_info: BluetoothServiceInfo) -> iBeaconAdvertisement | None:
         cypress_humidity=125 * ((major & 0xFF) * 256) / 65536 - 6.0,
         rssi=service_info.rssi,
         source=service_info.source,
-        distance=calculate_distance_meters(power, service_info.rssi),
+        distance=round(distance, 1) if distance is not None else None,
     )
 
 
